import cv2
# from videowriter.video_writer import VideoWriterWrapper
from src.Cvwriter.video_writer import VideoWriterWrapper
# Create a VideoWriterWrapper instance
video_writer = VideoWriterWrapper('output.avi', 30, (640, 480))

# Capture video from webcam and save
capture = cv2.VideoCapture(0)
i = 0
while True:
    i += 1
    ret, frame = capture.read()
    if not ret:
        break
    
    # Process frame if needed
    
    # Write frame to video
    video_writer.write_frame(frame)
    video_writer.save_image(frame, i)
    
    cv2.imshow('Frame', frame)
    if cv2.waitKey(1) & 0xFF == ord('q'):
        break

# Release resources
capture.release()
video_writer.release()
cv2.destroyAllWindows()



import cv2
import os
class VideoWriterWrapper:
    def __init__(self, filename,  fps, frame_size,save=True):
        code = None
        if filename.endswith(".avi"):
            code = "XVID"
        if filename.endswith(".mp4"):
            code = 'MPEG'
        if filename.endswith(".h265"):
            code = "HEVC"
        if save == True:
            self.writer = cv2.VideoWriter(filename, cv2.VideoWriter_fourcc(*f'{code}'), fps, frame_size)

    def write_frame(self, frame):
        self.writer.write(frame)

    def save_image(self,frame,name):
        folder = "save_crop"
        if not os.path.exists(folder):
            os.makedirs(folder)
        cv2.imwrite(f"{folder}/{name}.jpg", frame)

    def release(self):
        try: 
            self.writer.release()
        except:
            pass